==> cfengine3_3.6.2.orig.tar.gz: cfengine-3.6.2/cf-upgrade/command_line.h <==
/*
   Copyright (C) CFEngine AS

   This file is part of CFEngine 3 - written and maintained by CFEngine AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commercial Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef COMMAND_LINE_H
#define COMMAND_LINE_H

#include <configuration.h>

/*
 * Upper boundary on the number of command line options.
 * We have 5 modifiers with one argument each (5 * 2 = 10). Then we have
 * a maximum of CF_UPGRADE_MAX_ARGUMENTS for the upgrade utility itself.
 */
#define COMMAND_LINE_OPTIONS    (10 + CF_UPGRADE_MAX_ARGUMENTS)

/**
  @brief Parsing of the command line arguments.
  @param argc Number or arguments.
  @param argv Array containing the arguments.
  @param configuration Structure containing the configuration
  @return 0 if successful, -1 if error.
  */
int parse(int argc, char *argv[], Configuration **configuration);

#endif // COMMAND_LINE_H

==> cfengine3_3.10.2.orig.tar.gz: cfengine-3.10.2/cf-upgrade/command_line.h <==
/*
   Copyright 2017 Northern.tech AS

   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commercial Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef COMMAND_LINE_H
#define COMMAND_LINE_H

#include <configuration.h>

/*
 * Upper boundary on the number of command line options.
 * We have 5 modifiers with one argument each (5 * 2 = 10). Then we have
 * a maximum of CF_UPGRADE_MAX_ARGUMENTS for the upgrade utility itself.
 */
#define COMMAND_LINE_OPTIONS    (10 + CF_UPGRADE_MAX_ARGUMENTS)

/**
  @brief Parsing of the command line arguments.
  @param argc Number or arguments.
  @param argv Array containing the arguments.
  @param configuration Structure containing the configuration
  @return 0 if successful, -1 if error.
  */
int parse(int argc, char *argv[], Configuration **configuration);

#endif // COMMAND_LINE_H
